namespace efl { 
inline ::efl::eolian::return_traits<void>::type File::file_get( ::efl::eolian::out_traits< ::efl::eina::string_view>::type file,  ::efl::eolian::out_traits< ::efl::eina::string_view>::type key) const
{
   const char * __out_param_file = {};
   const char * __out_param_key = {};
    ::efl_file_get(this->_eo_ptr()
      , & __out_param_file
      , & __out_param_key);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::eina::string_view>::type, const char *>(file, __out_param_file);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::eina::string_view>::type, const char *>(key, __out_param_key);
}
inline ::efl::eolian::return_traits<bool>::type File::file_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type file,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const
{
   Eina_Bool __return_value =  ::efl_file_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(file)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(key));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type File::async_get() const
{
   Eina_Bool __return_value =  ::efl_file_async_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::async_set( ::efl::eolian::in_traits<bool>::type async) const
{
    ::efl_file_async_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(async));
}
inline ::efl::eolian::return_traits<bool>::type File::save( ::efl::eolian::in_traits< ::efl::eina::string_view>::type file,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type flags) const
{
   Eina_Bool __return_value =  ::efl_file_save(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(file)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(key)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(flags));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::eject() const
{
    ::efl_file_eject(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type File::async_wait() const
{
   Eina_Bool __return_value =  ::efl_file_async_wait(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace efl { 
inline ::efl::eolian::return_traits<void>::type File::file_get( ::efl::eolian::out_traits< ::efl::eina::string_view>::type file,  ::efl::eolian::out_traits< ::efl::eina::string_view>::type key) const
{
   const char * __out_param_file = {};
   const char * __out_param_key = {};
    ::efl_file_get(this->_eo_ptr()
      , & __out_param_file
      , & __out_param_key);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::eina::string_view>::type, const char *>(file, __out_param_file);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< ::efl::eina::string_view>::type, const char *>(key, __out_param_key);
}
inline ::efl::eolian::return_traits<bool>::type File::file_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type file,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type key) const
{
   Eina_Bool __return_value =  ::efl_file_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(file)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(key));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type File::async_get() const
{
   Eina_Bool __return_value =  ::efl_file_async_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::async_set( ::efl::eolian::in_traits<bool>::type async) const
{
    ::efl_file_async_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(async));
}
inline ::efl::eolian::return_traits<bool>::type File::save( ::efl::eolian::in_traits< ::efl::eina::string_view>::type file,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type key,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type flags) const
{
   Eina_Bool __return_value =  ::efl_file_save(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(file)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(key)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(flags));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::eject() const
{
    ::efl_file_eject(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type File::async_wait() const
{
   Eina_Bool __return_value =  ::efl_file_async_wait(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline efl::File::operator ::efl::File() const { return *static_cast< ::efl::File const*>(static_cast<void const*>(this)); }
inline efl::File::operator ::efl::File&() { return *static_cast< ::efl::File*>(static_cast<void*>(this)); }
inline efl::File::operator ::efl::File const&() const { return *static_cast< ::efl::File const*>(static_cast<void const*>(this)); }
} }

